@@ -158,21 +158,21 @@ grn_obj_is_builtin(grn_ctx *ctx, grn_obj *obj)
   return grn_id_is_builtin(ctx, id);
 }
 
-grn_bool
+bool
 grn_obj_is_bulk(grn_ctx *ctx, grn_obj *obj)
 {
   if (!obj) {
-    return GRN_FALSE;
+    return false;
   }
 
   return obj->header.type == GRN_BULK;
 }
 
-grn_bool
+bool
 grn_obj_is_text_family_bulk(grn_ctx *ctx, grn_obj *obj)
 {
   if (!grn_obj_is_bulk(ctx, obj)) {
-    return GRN_FALSE;
+    return false;
   }
 
   return GRN_TYPE_IS_TEXT_FAMILY(obj->header.domain);
@@ -268,13 +268,13 @@ grn_obj_is_db(grn_ctx *ctx, grn_obj *obj)
   return obj->header.type == GRN_DB;
 }
 
-grn_bool
+bool
 grn_obj_is_table(grn_ctx *ctx, grn_obj *obj)
 {
-  grn_bool is_table = GRN_FALSE;
+  bool is_table = false;
 
   if (!obj) {
-    return GRN_FALSE;
+    return false;
   }
 
   switch (obj->header.type) {
@@ -282,7 +282,7 @@ grn_obj_is_table(grn_ctx *ctx, grn_obj *obj)
   case GRN_TABLE_HASH_KEY:
   case GRN_TABLE_PAT_KEY:
   case GRN_TABLE_DAT_KEY:
-    is_table = GRN_TRUE;
+    is_table = true;
     break;
   default:
     break;
@@ -294,7 +294,7 @@ grn_obj_is_table(grn_ctx *ctx, grn_obj *obj)
 bool
 grn_obj_is_table_with_key(grn_ctx *ctx, grn_obj *obj)
 {
-  grn_bool is_table_with_key = false;
+  bool is_table_with_key = false;
 
   if (!obj) {
     return false;
@@ -315,7 +315,7 @@ grn_obj_is_table_with_key(grn_ctx *ctx, grn_obj *obj)
 bool
 grn_obj_is_table_with_value(grn_ctx *ctx, grn_obj *obj)
 {
-  grn_bool is_table_with_value = false;
+  bool is_table_with_value = false;
 
   if (!obj) {
     return false;
@@ -453,20 +453,20 @@ grn_obj_is_result_set(grn_ctx *ctx, grn_obj *obj)
   return flags & GRN_OBJ_WITH_SUBREC;
 }
 
-grn_bool
+bool
 grn_obj_is_column(grn_ctx *ctx, grn_obj *obj)
 {
-  grn_bool is_column = GRN_FALSE;
+  bool is_column = false;
 
   if (!obj) {
-    return GRN_FALSE;
+    return false;
   }
 
   switch (obj->header.type) {
   case GRN_COLUMN_FIX_SIZE:
   case GRN_COLUMN_VAR_SIZE:
   case GRN_COLUMN_INDEX:
-    is_column = GRN_TRUE;
+    is_column = true;
   default:
     break;
   }
@@ -484,11 +484,11 @@ grn_obj_is_number_family_column(grn_ctx *ctx, grn_obj *obj)
   return grn_type_id_is_number_family(ctx, grn_obj_get_range(ctx, obj));
 }
 
-grn_bool
+bool
 grn_obj_is_scalar_column(grn_ctx *ctx, grn_obj *obj)
 {
   if (!grn_obj_is_column(ctx, obj)) {
-    return GRN_FALSE;
+    return false;
   }
 
   return (obj->header.flags & GRN_OBJ_COLUMN_TYPE_MASK) ==
@@ -515,11 +515,11 @@ grn_obj_is_number_family_scalar_column(grn_ctx *ctx, grn_obj *obj)
   return grn_type_id_is_number_family(ctx, grn_obj_get_range(ctx, obj));
 }
 
-grn_bool
+bool
 grn_obj_is_vector_column(grn_ctx *ctx, grn_obj *obj)
 {
   if (!grn_obj_is_column(ctx, obj)) {
-    return GRN_FALSE;
+    return false;
   }
 
   return (
@@ -537,11 +537,11 @@ grn_obj_is_text_family_vector_column(grn_ctx *ctx, grn_obj *obj)
   return grn_type_id_is_text_family(ctx, grn_obj_get_range(ctx, obj));
 }
 
-grn_bool
+bool
 grn_obj_is_weight_vector_column(grn_ctx *ctx, grn_obj *obj)
 {
   if (!grn_obj_is_vector_column(ctx, obj)) {
-    return GRN_FALSE;
+    return false;
   }
 
   return (obj->header.flags & GRN_OBJ_WITH_WEIGHT) == GRN_OBJ_WITH_WEIGHT;
@@ -578,66 +578,66 @@ grn_obj_is_reference_column(grn_ctx *ctx, grn_obj *obj)
   }
 }
 
-grn_bool
+bool
 grn_obj_is_data_column(grn_ctx *ctx, grn_obj *obj)
 {
   if (!grn_obj_is_column(ctx, obj)) {
-    return GRN_FALSE;
+    return false;
   }
 
   return obj->header.type == GRN_COLUMN_FIX_SIZE ||
          obj->header.type == GRN_COLUMN_VAR_SIZE;
 }
 
-grn_bool
+bool
 grn_obj_is_index_column(grn_ctx *ctx, grn_obj *obj)
 {
   if (!grn_obj_is_column(ctx, obj)) {
-    return GRN_FALSE;
+    return false;
   }
 
   return obj->header.type == GRN_COLUMN_INDEX;
 }
 
-grn_bool
+bool
 grn_obj_is_accessor(grn_ctx *ctx, grn_obj *obj)
 {
   if (!obj) {
-    return GRN_FALSE;
+    return false;
   }
 
   return obj->header.type == GRN_ACCESSOR;
 }
 
-grn_bool
+bool
 grn_obj_is_id_accessor(grn_ctx *ctx, grn_obj *obj)
 {
   grn_accessor *accessor;
 
   if (!grn_obj_is_accessor(ctx, obj)) {
-    return GRN_FALSE;
+    return false;
   }
 
   accessor = (grn_accessor *)obj;
   if (accessor->next) {
-    return GRN_FALSE;
+    return false;
   }
 
   return accessor->action == GRN_ACCESSOR_GET_ID;
 }
 
-grn_bool
+bool
 grn_obj_is_key_accessor(grn_ctx *ctx, grn_obj *obj)
 {
   grn_accessor *accessor;
 
   if (!grn_obj_is_accessor(ctx, obj)) {
-    return GRN_FALSE;
+    return false;
   }
 
   accessor = (grn_accessor *)obj;
   if (accessor->next) {
-    return GRN_FALSE;
+    return false;
   }
 
   return accessor->action == GRN_ACCESSOR_GET_KEY;
@@ -1387,6 +1387,18 @@ grn_obj_name_is_column(grn_ctx *ctx, const char *name, int name_len)
   return memchr(name, GRN_DB_DELIMITER, (size_t)name_len) != NULL;
 }
 
+bool
+grn_obj_is_empty(grn_ctx *ctx, grn_obj *obj, grn_id id)
+{
+  if (obj->header.type == GRN_COLUMN_VAR_SIZE) {
+    return grn_ja_is_empty(ctx, (grn_ja *)obj, id);
+  }
+  ERR(GRN_FUNCTION_NOT_IMPLEMENTED,
+      "[obj][is-empty] unsupported type: %s",
+      grn_obj_type_to_string(obj->header.type));
+  return false;
+}
+
 grn_io *
 grn_obj_get_io(grn_ctx *ctx, grn_obj *obj)
 {
